@@ -1,7 +1,7 @@
 from typing import List, Union
 import requests
 
-BASE_URL = "http://www.api.automait.ai/"
+BASE_URL = "http://api.automait.ai/"
 
 
 class Client():
@@ -29,6 +29,7 @@ class Client():
             url=BASE_URL+"login",
             params=payload
         )
+        print(r)
         if r.status_code == 200:
             return True
         else:
